
# hack_anything

An efficient and robust library to hack anything.


## Installation

Install project with pip

```bash
  pip install hack_anything  
```
    
## Usage/Examples

```python
from hack_anything import hack_tool

hack_tool.hack("Universal.Co")

```

